==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sk.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta",
    "Loading accounts" : "Nahrávanie účtov",
    "Error while loading the accounts." : "Chyba pri načítaní účtov.",
    "Can not load this folder." : "Nie je možné načítať túto zložku.",
    "Searching for {query}" : "Vyhľadávam {query}",
    "Error while deleting message." : "Chyba pri mazaní správy.",
    "Forwarded message" : "Preposlané správy",
    "Choose a folder to store the attachment in" : "Vyberte priečinok pre uloženie prílohy",
    "Attachments saved to Files." : "Prílohy sú uložené do Súborov.",
    "Attachment saved to Files." : "Príloha je uložená do Súborov.",
    "Error while saving attachments to Files." : "Chyba pri ukladaní príloh do Súborov.",
    "Error while saving attachment to Files." : "Chyba pri ukladaní prílohy do Súborov.",
    "Message flag could not be set." : "Nepodarilo sa nastaviť príznak správy.",
    "Could not move message." : "Správu nebolo možné presunúť.",
    "Invalid account" : "Neplatný účet",
    "Invalid folder" : "Neplatný priečinok",
    "Error while creating the account: " : "Nastala chyba počas vytvárania účtu:",
    "Unknown error" : "Neznáma chyba",
    "Error while updating the account: " : "Chyba pri aktualizácii účtu:",
    "All inboxes" : "Všetky doručené",
    "you" : "vy",
    "Send message to {email}" : "Odoslať správu na {email}",
    "Could not load {tag}{name}{endtag}" : "Nedá sa načítať {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Vyskytol sa problém pri načítaní {tag}{name}{endtag}",
    "Could not load your message" : "Nepodarilo sa načítať vašu správu",
    "Could not load the desired message" : "Nepodarilo sa načítať požadovanú správu",
    "Could not load the message" : "Správu sa nepodarilo sa načítať",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová správa\nod {from}","%n nové správy\nod {from}","%n nových správ\nod {from}","%n nových správ\nod {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Uložiť",
    "Saved" : "Uložené",
    "Show all folders" : "Zobraziť všetky priečinky",
    "Collapse folders" : "Zvinúť priečinky",
    "Error while deleting account." : "Chyba pri mazaní účtu.",
    "Choose a file to add as attachment" : "Zvoľte súbor, ktorý chcete pridať ako prílohu.",
    "An error occurred while uploading {fname}" : "Počas nahrávania {fname} sa vyskytla chyba",
    "Reply" : "Odpoveď",
    "Send" : "Odoslať",
    "Sending …" : "Odosielam ...",
    "Message sent!" : "Správa odoslaná!",
    "Server error" : "Chyba servera",
    "An unknown error occurred" : "Nastala neznáma chyba",
    "Opening HTML drafts is not supported yet." : "Otváranie HTML šablón ešte nie je podporované.",
    "No writable calendars found" : "Nenašli sa žiadne kalendáre s právom zápisu",
    "Error while importing the calendar event" : "Nastala chyba pri importovaní udalosti kalendára",
    "Error while downloading calendar event" : "Nastala chyba pri sťahovaní udalosti kalendára",
    "& others" : "& iné",
    "Error while loading messages." : "Chyba počas načítavania správ.",
    "Error while refreshing messages." : "Chyba počas obnovovania správ.",
    "Setting up your account" : "Nastavenie vášho účtu",
    "Inbox" : "Doručené",
    "Sent" : "Odoslané",
    "Drafts" : "Koncept",
    "Archive" : "Archív",
    "Trash" : "Kôš",
    "Junk" : "Spam",
    "All" : "Všetky",
    "Favorites" : "Obľúbené",
    "Auto detect failed. Please use manual mode." : "Automatická detekcia zlyhala. Prosím, použite manuálny režim.",
    "Updating account failed: " : "Aktualizácia účtu zlyhala:",
    "Creating account failed: " : "Vytvorenie účtu zlyhalo:",
    "Delete permanently" : "Zmazať  natrvalo",
    "IMAP web client" : "IMAP web klient",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "E-mailový klient, jednoduchý na používanie, ktorý sa pripája k vášmu poskytovateľovi e-mailov pomocou IMAP a SMTP.",
    "Error loading message" : "Chyba načítavania správy",
    "Settings" : "Nastavenia",
    "Forwarding to %s" : "Preposielam na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kliknite sem, ak nebudete automaticky presmerovaní v priebehu pár sekúnd.",
    "Redirect" : "Presmerovať",
    "The link leads to %s" : "Odkaz smeruje na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ak si neprajete navštíviť stránku, možete sa vátiť na <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Pokračovať na %s",
    "Delete account" : "Zmazať účet",
    "Try again" : "Skúste znovu",
    "New message" : "Nová správa",
    "Account Settings" : "Nastavenia účtu",
    "Aliases" : "Aliasy",
    "Mail address" : "Emailová adresa",
    "Display Name" : "Zobrazované meno",
    "Account" : "Účet",
    "Delete" : "Zmazať",
    "Keyboard shortcuts" : "Klávesové skratky",
    "Speed up your Mail experience with these quick shortcuts." : "Zefektívnite svoju prácu s Mailom pomocou týchto rýchlych skratiek.",
    "Compose new message" : "Nová správa",
    "Newer message" : "Novšia správa",
    "Older message" : "Staršia správa",
    "Toggle star" : "Prepnúť hviezdičku",
    "Toggle unread" : "Prepnúť neprečítané",
    "Search" : "Hľadať",
    "Refresh" : "Obnoviť",
    "Connect your mail account" : "Pripojiť Váš mailový účet",
    "Name" : "Meno",
    "Mail Address" : "Emailová adresa",
    "Password" : "Heslo",
    "Manual configuration" : "Manuálne nastavenia",
    "IMAP Host" : "IMAP hostiteľ",
    "IMAP security" : "IMAP zabezpečenie",
    "None" : "Žiadny",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP číslo portu",
    "IMAP User" : "IMAP používateľ",
    "IMAP Password" : "IMAP heslo",
    "SMTP Host" : "SMTP hostiteľ",
    "SMTP security" : "SMTP zabezpečenie",
    "SMTP Port" : "SMTP číslo portu",
    "SMTP User" : "SMTP používateľ",
    "SMTP Password" : "SMTP heslo",
    "Connect" : "Pripojiť",
    "from" : "od",
    "to" : "komu",
    "cc" : "kópia",
    "bcc" : "skrytá kópia",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Všimnite si, že mail prišiel z adresy noreply (neodpovedať) takže vašu odpoveď si pravdepodobne nikto neprečíta.",
    "Subject" : "Predmet",
    "Save all to Files" : "Uložiť všetko do Súborov",
    "Add mail account" : "Pridať mailový účet",
    "Use Gravatar and favicon avatars" : "Použiť Gravatar a favicon avatary",
    "No search results for" : "Žiadne výsledky vyhľadávania pre",
    "The images have been blocked to protect your privacy." : "Obrázky boli zablokované pre ochranu Vášho súkromia.",
    "Show images from this sender" : "Zobraziť obrázky od tohoto odosielateľa",
    "Forward" : "Preposlať",
    "No messages in this folder" : "Žiadne správy v tomto priečinku!",
    "Upload attachment" : "Nahrať prílohu",
    "Add attachment from Files" : "Pridať prílohu zo Súborov",
    "Import into calendar" : "Importovať do kalendára",
    "Download attachment" : "Stiahnuť prílohu",
    "Save to Files" : "Uložiť do Súborov"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-mail-0.14.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sk.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta",
    "Inbox" : "Doručené",
    "Sent" : "Odoslané",
    "Drafts" : "Koncept",
    "Archive" : "Archív",
    "Trash" : "Kôš",
    "Junk" : "Spam",
    "All" : "Všetky",
    "Favorites" : "Obľúbené",
    "Auto detect failed. Please use manual mode." : "Automatická detekcia zlyhala. Prosím, použite manuálny režim.",
    "Updating account failed: " : "Aktualizácia účtu zlyhala:",
    "Creating account failed: " : "Vytvorenie účtu zlyhalo:",
    "Delete permanently" : "Zmazať  natrvalo",
    "IMAP web client" : "IMAP web klient",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "E-mailový klient, jednoduchý na používanie, ktorý sa pripája k vášmu poskytovateľovi e-mailov pomocou IMAP a SMTP.",
    "Name" : "Meno",
    "Mail Address" : "Emailová adresa",
    "Password" : "Heslo",
    "IMAP Host" : "IMAP hostiteľ",
    "None" : "Žiadny",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP číslo portu",
    "IMAP User" : "IMAP používateľ",
    "IMAP Password" : "IMAP heslo",
    "SMTP Host" : "SMTP hostiteľ",
    "SMTP Port" : "SMTP číslo portu",
    "SMTP User" : "SMTP používateľ",
    "SMTP Password" : "SMTP heslo",
    "Connect" : "Pripojiť",
    "Add mail account" : "Pridať mailový účet",
    "Use Gravatar and favicon avatars" : "Použiť Gravatar a favicon avatary",
    "Keyboard shortcuts" : "Klávesové skratky",
    "from" : "od",
    "to" : "komu",
    "cc" : "kópia",
    "bcc" : "skrytá kópia",
    "Subject" : "Predmet",
    "Sending …" : "Odosielam ...",
    "Message sent!" : "Správa odoslaná!",
    "Send" : "Odoslať",
    "Upload attachment" : "Nahrať prílohu",
    "Add attachment from Files" : "Pridať prílohu zo Súborov",
    "Choose a file to add as attachment" : "Zvoľte súbor, ktorý chcete pridať ako prílohu.",
    "No messages in this folder" : "Žiadne správy v tomto priečinku!",
    "Delete" : "Zmazať",
    "Could not load your message" : "Nepodarilo sa načítať vašu správu",
    "Import into calendar" : "Importovať do kalendára",
    "Download attachment" : "Stiahnuť prílohu",
    "Save to Files" : "Uložiť do Súborov",
    "Choose a folder to store the attachment in" : "Vyberte priečinok pre uloženie prílohy",
    "Save all to Files" : "Uložiť všetko do Súborov",
    "The images have been blocked to protect your privacy." : "Obrázky boli zablokované pre ochranu Vášho súkromia.",
    "New message" : "Nová správa",
    "Settings" : "Nastavenia",
    "Show all folders" : "Zobraziť všetky priečinky",
    "Collapse folders" : "Zvinúť priečinky",
    "Speed up your Mail experience with these quick shortcuts." : "Zefektívnite svoju prácu s Mailom pomocou týchto rýchlych skratiek.",
    "Compose new message" : "Nová správa",
    "Newer message" : "Novšia správa",
    "Older message" : "Staršia správa",
    "Toggle star" : "Prepnúť hviezdičku",
    "Toggle unread" : "Prepnúť neprečítané",
    "Search" : "Hľadať",
    "Refresh" : "Obnoviť",
    "Connect your mail account" : "Pripojiť Váš mailový účet",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová správa\nod {from}","%n nové správy\nod {from}","%n nových správ\nod {from}","%n nových správ\nod {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "All inboxes" : "Všetky doručené",
    "Could not load {tag}{name}{endtag}" : "Nedá sa načítať {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Vyskytol sa problém pri načítaní {tag}{name}{endtag}",
    "Could not load the desired message" : "Nepodarilo sa načítať požadovanú správu",
    "Could not load the message" : "Správu sa nepodarilo sa načítať",
    "Error loading message" : "Chyba načítavania správy",
    "Forwarding to %s" : "Preposielam na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kliknite sem, ak nebudete automaticky presmerovaní v priebehu pár sekúnd.",
    "Redirect" : "Presmerovať",
    "The link leads to %s" : "Odkaz smeruje na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ak si neprajete navštíviť stránku, možete sa vátiť na <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Pokračovať na %s"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
